@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2024 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 """
@@ -14,10 +14,11 @@ This private submodule is *not* intended for importation by downstream callers.
 from beartype.roar._roarwarn import _BeartypeUtilCallableWarning
 # from beartype.typing import Dict
 from beartype._cave._cavefast import NumberType
-from beartype._data.hint.datahinttyping import TypeWarning
+from beartype._data.typing.datatyping import TypeWarning
 from beartype._data.kind.datakindtext import CHARS_PUNCTUATION
-from beartype._util.utilobject import get_object_basename_scoped
+from beartype._util.utilobject import get_object_basename_scoped_or_none
 from collections.abc import Callable
+from pprint import saferepr
 
 # ....................{ REPRESENTERS                       }....................
 def represent_object(
@@ -86,36 +87,20 @@ def represent_object(
     '''
     assert isinstance(max_len, int), f'{repr(max_len)} not integer.'
 
-    #FIXME: Render this safe against infinitely recursive data structures.
-    #Unfortunately, we *CANNOT* call the standard pprint.saferepr() function to
-    #do so, as that function is *OUTRAGEOUSLY* slow on worst-case edge cases.
-    #Instead, we'll need to implement our own performant saferepr()
-    #alternative. Fortunately, note that someone's already done so: the popular
-    #BSD-licensed Celerity project, whose celerity.utils.saferepr.saferepr()
-    #function claims to actually be faster than the repr() builtin under
-    #certain circumstances. While impressive, repurposing Celerity's saferepr()
-    #implementation for @beartype will be non-trivial; that function internally
-    #leverages a number of non-trivial internal functions, including a
-    #streaming iterator that appears to be performing some sort of ad-hoc
-    #tokenization (!) on the input object's string representation. Although
-    #that submodule is less than 300 lines, that's 300 *INTENSE* lines.
-    #Nonetheless, we'll need to do this sooner or later. Currently, later. By
-    #the time you read this next, probably sooner. Until someone pounds their
-    #fists on our issue tracker, let's pretend this isn't a compelling concern.
-    #See also:
+    #FIXME: [SPEED] Note that the popular BSD-licensed Celerity project's
+    #celerity.utils.saferepr.saferepr() function claims to actually be faster
+    #than the repr() builtin under certain circumstances. While impressive,
+    #repurposing Celerity's saferepr() implementation for @beartype will be
+    #non-trivial; that function internally leverages a number of non-trivial
+    #internal functions, including a streaming iterator that appears to be
+    #performing some sort of ad-hoc tokenization (!) on the input object's
+    #string representation. Although that submodule is less than 300 lines,
+    #that's 300 *INTENSE* lines. Until someone pounds their fists on our issue
+    #tracker (so, never), let's pretend no one cares. See also:
     #   https://github.com/celery/celery/blob/master/celery/utils/saferepr.py
-    #FIXME: Actually, a trivial way to do this without going full-Celery would
-    #be to just leverage the EAFP principle: e.g.,
-    #    try:
-    #        obj_repr = repr(obj)
-    #    except RecursionError:
-    #        from pprint import saferepr
-    #        obj_repr = saferepr(obj)
-    #
-    #Clearly, that will still be slightly less efficient than the
-    #Celery-oriented approach -- but also considerably easier. *sigh*
 
-    # String describing this object. Note that:
+    # For efficiency, initially attempt to *NON-RECURSIVELY* introspect the
+    # machine-readable string describing this object. Note that:
     # * This representation quote-protects all newlines in this representation.
     #   Ergo, "\n" *MUST* be matched as r"\n" instead below.
     # * For debuggability, the verbose (albeit less readable) output of repr()
@@ -126,11 +111,14 @@ def represent_object(
     #   pprint.saferepr() is extremely unoptimized and thus susceptible to
     #   extreme performance regressions when passed a worst-case object (e.g.,
     #   deeply nested container).
-    obj_repr = repr(obj)
-
-    #FIXME: Uncomment to exhibit a performance regression.
-    # from pprint import saferepr
-    # obj_repr = saferepr(obj)
+    try:
+        obj_repr = repr(obj)
+    # If doing so fails with a recursion error, the passed object is recursive.
+    # In this case, fallback to recursively introspecting the machine-readable
+    # string describing this object. Note that doing so is *EXTREMELY*
+    # inefficient and thus performed only as a last-ditch desperate fallback.
+    except RecursionError:
+        obj_repr = saferepr(obj)
 
     # If this representation is empty, return empty double-quotes. Although
     # most objects (including outlier singletons like "None" and the empty
@@ -154,6 +142,8 @@ def represent_object(
     # double-quote this representation for disambiguity with preceding
     # characters (e.g., sequence indices).
         obj_repr = f'"{obj_repr}"'
+    # Else, this representation is either prefixed by punctuation *OR* an
+    # instance of a class whose representations do *NOT* benefit from quoting.
 
     # If this representation exceeds this maximum length...
     if len(obj_repr) > max_len:
@@ -163,6 +153,7 @@ def represent_object(
         # Truncate this representation to this maximum length.
         obj_repr = truncate_str(text=obj_repr, max_len=max_len)
         # print(f'obj repr truncated: {obj_repr}')
+    # Else, this representation is less than or equal to this maximum length.
 
     # Return this representation.
     return obj_repr
@@ -212,7 +203,7 @@ def represent_func(
     from beartype._util.func.utilfunccode import get_func_code_or_none
     from beartype._util.func.utilfunctest import is_func_lambda
 
-    # If this callable is a pure-Python lambda function, return either:
+    # If that callable is a pure-Python lambda function, return either:
     # * If this lambda is defined by an on-disk script or module source file,
     #   the exact substring of that file defining this lambda.
     # * Else (e.g., if this lambda is dynamically defined in-memory), a
@@ -222,10 +213,24 @@ def represent_func(
             get_func_code_or_none(func=func, warning_cls=warning_cls) or
             '<lambda>'
         )
-    # Else, this callable is *NOT* a pure-Python lambda function.
+    # Else, that callable is *NOT* a pure-Python lambda function.
 
-    # Return the fully-qualified name of this non-lambda function.
-    return get_object_basename_scoped(func)
+    #FIXME: Actually, we should be calling a new get_object_name_or_none()
+    #function instead -- but that function currently doesn't exist and we're
+    #lazy. The issue with get_object_basename_scoped_or_none() is that this
+    #getter fails to return the module name of this function. *shrug*
+    func_basename_scoped = get_object_basename_scoped_or_none(func)
+
+    # If that callable is named, return this name.
+    if func_basename_scoped:
+        return func_basename_scoped
+    # Else, that callable is unnamed due to failing to define both the
+    # "__qualname__" and "__name__" dunder attributes and thus have *NO* names.
+    # Although most callables are named, some are not. This includes:
+    # * Callable "functools.partial" objects.
+
+    # Return the machine-readable representation of that callable as a fallback.
+    return repr(func)
 
 # ....................{ REPRESENTERS ~ pith                }....................
 def represent_pith(
